#!/bin/csh 
### This script helps to configure the parameters before run the wrf_hydro.exe or dhydro.exe
## Step 1.  edit the list.txt to input the stations. 
## Step 2. DOMAIN/Fulldom_finemesh.nc need to backup, since this part will modify it. 
## Step 3. make sure  aggFactor and dxRT are consistent with hydro.namelist.
## Step 4. run the script

set mpitasks = 1   ### total number of mpi tasks
set streamOrder = 1 ### set the threshold of stream order to increase the accuracy in searching the observation stations.
                    ## The small order stream will not be searched. 
set aggFactor = 20  ### the ratio of the resolution between land grid and land routing grid
set dxRT = 50      ### horizontal resolution in land routing domain (meters)


###--------------no need to change below -------------------

set NAMELIST = hydro.namelist
rm -f *.nc


if(! -e DOMAIN/Fulldom_finemesh.nc) then 
  echo "Error: no DOMAIN/Fulldom_finemesh.nc"
  exit
endif

if(! -e DOMAIN/geo_finemesh.nc) then 
  echo "Error: no DOMAIN/geo_finemesh.nc"
  exit
endif

### create the wrfinput_d01 
if(! -e DOMAIN/wrfinput_d01) then 
  if(-e DOMAIN/geo_finemesh.nc) ./cwrfInput.exe DOMAIN/geo_finemesh.nc DOMAIN/wrfinput_d01
endif

if (! -e DOMAIN/Fulldom_finemesh.nc.org) cp DOMAIN/Fulldom_finemesh.nc DOMAIN/Fulldom_finemesh.nc.org

if(! -e ${NAMELIST}.bak_d) cp $NAMELIST ${NAMELIST}.bak_d
if(! -e namelist.hrldas.bak_d) cp namelist.hrldas namelist.hrldas.bak_d

sed "s,^.*FORC_TYP.*, FORC_TYP = 4,;" \
                namelist.hrldas >& namelist.hrldas.tmp; mv namelist.hrldas.tmp namelist.hrldas

sed "s,^.*outStatic .*, outStatic  = 1,;" \
                ${NAMELIST} >& ${NAMELIST}.tmp; mv ${NAMELIST}.tmp ${NAMELIST}
sed "s,^.*DABE .*, DABE  = 0,;" \
                ${NAMELIST} >& ${NAMELIST}.tmp; mv ${NAMELIST}.tmp ${NAMELIST}

mpirun -np $mpitasks ./wrf_hydro.exe
if($status != 0) then 
   echo "Error failed adt step 1 "
   exit
endif
set nnTmp = `wc -l staticData.txt`
echo $nnTmp[1]
echo " ./find.exe $streamOrder $nnTmp[1] $aggFactor DOMAIN/geo_finemesh.nc "

## First to run this command find the watershed. 
## Since the obs could be in the middle of the watershed, this will find partial of the watershed.
./find.exe $streamOrder $nnTmp[1] $aggFactor DOMAIN/geo_finemesh.nc
if($status != 0) then 
   echo "Error failed adt step 2 "
   exit
endif

## Second find the end point of the watershed and run the find.exe again. 
## Now it will find all points of the watershed, extended to the domain boundary.
if(-e bucket.CSV) then
  set ll = `tail -10 bucket.CSV|head -1| sed "s/,/ /g"`
  set lat = $ll[3]
  set lon = $ll[2]
  cp list.txt list.txt.bak_d
  echo "$lat $lon 0 -9999 " >> list.txt
  ./find.exe $streamOrder $nnTmp[1] $aggFactor DOMAIN/geo_finemesh.nc
if($status != 0) then 
   echo "Error failed adt step 3 "
   exit
endif
endif

## Using the bucket_full2.CSV to cover the whole domain.
## Using the bucket2.CSV to cover the selected river.
## ./createBucket.exe  DOMAIN/Fulldom_finemesh.nc bucket_full2.CSV
if(-e bucket2.CSV) then
   ./createBucket.exe  DOMAIN/Fulldom_finemesh.nc bucket2.CSV
if($status != 0) then 
   echo "Error failed adt step 4 "
   exit
endif
else
   ./createBucket.exe  DOMAIN/Fulldom_finemesh.nc bucket2_full.CSV 
if($status != 0) then 
   echo "Error failed adt step 5 "
   exit
endif
endif


## Since the Fulldom has been changed. We need to get the new parameters, all CSV files. 
cp station_list.txt station_list.txt.bakd
mv list.txt.bak_d list.txt
rm -f *.nc 
mpirun -np $mpitasks ./wrf_hydro.exe
if($status != 0) then 
   echo "Error failed adt step 6 "
   exit
endif
set nnTmp = `wc -l staticData.txt`

echo "./find.exe $streamOrder $nnTmp[1] $aggFactor DOMAIN/geo_finemesh.nc" 

./find.exe $streamOrder $nnTmp[1] $aggFactor DOMAIN/geo_finemesh.nc
if($status != 0) then 
   echo "Error failed adt step 7 "
   exit
endif

### Update the station information to seg_info.nc file. 
echo " ./updateSeg.exe DOMAIN/geo_finemesh.nc DOMAIN/Fulldom_finemesh.nc $dxRT  $streamOrder"
./updateSeg.exe DOMAIN/geo_finemesh.nc DOMAIN/Fulldom_finemesh.nc $dxRT $streamOrder 
if($status != 0) then 
   echo "Error failed adt step 8 "
   exit
endif

### Create the watershed in seg_info.nc for each observation. 
echo "./createSegMask.exe DOMAIN/Fulldom_finemesh.nc $aggFactor "
./createSegMask.exe DOMAIN/Fulldom_finemesh.nc $aggFactor 
if($status != 0) then 
   echo "Error failed adt step 9 "
   exit
endif

mv ${NAMELIST}.bak_d $NAMELIST 
mv namelist.hrldas.bak_d namelist.hrldas 

echo "Finished successfully ! "

### Now you are ready to adjust the parameters. 
## Create the river geometry data
#./river_geo.exe narivs.shp.nc DOMAIN/Fulldom_finemesh.nc DOMAIN/geo_finemesh.nc stream_geo.nc 100 seg_info.nc
